@@ -4,11 +4,13 @@ from sqlglot import exp
 from sqlglot.dialects.dialect import (
     approx_count_distinct_sql,
     build_timestamp_trunc,
+    property_sql,
     rename_func,
     time_format,
     unit_to_str,
 )
 from sqlglot.dialects.mysql import MySQL
+from sqlglot.tokens import TokenType
 
 
 def _lag_lead_sql(self, expression: exp.Lag | exp.Lead) -> str:
@@ -38,9 +40,77 @@ class Doris(MySQL):
         FUNCTION_PARSERS = MySQL.Parser.FUNCTION_PARSERS.copy()
         FUNCTION_PARSERS.pop("GROUP_CONCAT")
 
+        PROPERTY_PARSERS = {
+            **MySQL.Parser.PROPERTY_PARSERS,
+            "PROPERTIES": lambda self: self._parse_wrapped_properties(),
+            "UNIQUE": lambda self: self._parse_composite_key_property(exp.UniqueKeyProperty),
+            "PARTITION BY": lambda self: self._parse_partition_by_opt_range(),
+        }
+
+        def _parse_partitioning_granularity_dynamic(self) -> exp.PartitionByRangePropertyDynamic:
+            self._match_text_seq("FROM")
+            start = self._parse_wrapped(self._parse_string)
+            self._match_text_seq("TO")
+            end = self._parse_wrapped(self._parse_string)
+            self._match_text_seq("INTERVAL")
+            number = self._parse_number()
+            unit = self._parse_var(any_token=True)
+            every = self.expression(exp.Interval, this=number, unit=unit)
+            return self.expression(
+                exp.PartitionByRangePropertyDynamic, start=start, end=end, every=every
+            )
+
+        def _parse_partition_definition(self) -> exp.Partition:
+            self._match_text_seq("PARTITION")
+
+            name = self._parse_id_var()
+            self._match_text_seq("VALUES")
+
+            if self._match_text_seq("LESS", "THAN"):
+                values = self._parse_wrapped_csv(self._parse_expression)
+                if len(values) == 1 and values[0].name.upper() == "MAXVALUE":
+                    values = [exp.var("MAXVALUE")]
+
+                part_range = self.expression(exp.PartitionRange, this=name, expressions=values)
+                return self.expression(exp.Partition, expressions=[part_range])
+
+            self._match(TokenType.L_BRACKET)
+            values = self._parse_csv(lambda: self._parse_wrapped_csv(self._parse_expression))
+
+            self._match(TokenType.R_BRACKET)
+            self._match(TokenType.R_PAREN)
+
+            part_range = self.expression(exp.PartitionRange, this=name, expressions=values)
+            return self.expression(exp.Partition, expressions=[part_range])
+
+        def _parse_partition_by_opt_range(
+            self,
+        ) -> exp.PartitionedByProperty | exp.PartitionByRangeProperty:
+            if not self._match_text_seq("RANGE"):
+                return super()._parse_partitioned_by()
+
+            partition_expressions = self._parse_wrapped_id_vars()
+            self._match_l_paren()
+
+            if self._match_text_seq("FROM", advance=False):
+                create_expressions = self._parse_csv(self._parse_partitioning_granularity_dynamic)
+            elif self._match_text_seq("PARTITION", advance=False):
+                create_expressions = self._parse_csv(self._parse_partition_definition)
+            else:
+                create_expressions = None
+
+            self._match_r_paren()
+
+            return self.expression(
+                exp.PartitionByRangeProperty,
+                partition_expressions=partition_expressions,
+                create_expressions=create_expressions,
+            )
+
     class Generator(MySQL.Generator):
         LAST_DAY_SUPPORTS_DATE_PART = False
         VARCHAR_REQUIRES_SIZE = False
+        WITH_PROPERTIES_PREFIX = "PROPERTIES"
 
         TYPE_MAPPING = {
             **MySQL.Generator.TYPE_MAPPING,
@@ -49,6 +119,12 @@ class Doris(MySQL):
             exp.DataType.Type.TIMESTAMPTZ: "DATETIME",
         }
 
+        PROPERTIES_LOCATION = {
+            **MySQL.Generator.PROPERTIES_LOCATION,
+            exp.UniqueKeyProperty: exp.Properties.Location.POST_SCHEMA,
+            exp.PartitionByRangeProperty: exp.Properties.Location.POST_SCHEMA,
+        }
+
         CAST_MAPPING = {}
         TIMESTAMP_FUNC_TYPES = set()
 
@@ -70,8 +146,10 @@ class Doris(MySQL):
             exp.Lag: _lag_lead_sql,
             exp.Lead: _lag_lead_sql,
             exp.Map: rename_func("ARRAY_MAP"),
+            exp.Property: property_sql,
             exp.RegexpLike: rename_func("REGEXP"),
             exp.RegexpSplit: rename_func("SPLIT_BY_STRING"),
+            exp.SchemaCommentProperty: lambda self, e: self.naked_property(e),
             exp.Split: rename_func("SPLIT_BY_STRING"),
             exp.StringToArray: rename_func("SPLIT_BY_STRING"),
             exp.StrToUnix: lambda self, e: self.func("UNIX_TIMESTAMP", e.this, self.format_time(e)),
@@ -559,3 +637,49 @@ class Doris(MySQL):
             "xor",
             "year",
         }
+
+        def partition_sql(self, expression: exp.Partition) -> str:
+            parent = expression.parent
+            if isinstance(parent, exp.PartitionByRangeProperty):
+                return ", ".join(self.sql(e) for e in expression.expressions)
+            return super().partition_sql(expression)
+
+        def partitionrange_sql(self, expression: exp.PartitionRange) -> str:
+            name = self.sql(expression, "this")
+            values = expression.expressions
+
+            if len(values) != 1:
+                # Multiple values: use VALUES [ ... )
+                if values and isinstance(values[0], list):
+                    values_sql = ", ".join(
+                        f"({', '.join(self.sql(v) for v in inner)})" for inner in values
+                    )
+                else:
+                    values_sql = ", ".join(f"({self.sql(v)})" for v in values)
+
+                return f"PARTITION {name} VALUES [{values_sql})"
+
+            return f"PARTITION {name} VALUES LESS THAN ({self.sql(values[0])})"
+
+        def partitionbyrangepropertydynamic_sql(self, expression):
+            # Generates: FROM ("start") TO ("end") INTERVAL N UNIT
+            start = self.sql(expression, "start")
+            end = self.sql(expression, "end")
+            every = expression.args.get("every")
+
+            if every:
+                number = self.sql(every, "this")
+                interval = f"INTERVAL {number} {self.sql(every, 'unit')}"
+            else:
+                interval = ""
+
+            return f"FROM ({start}) TO ({end}) {interval}"
+
+        def partitionbyrangeproperty_sql(self, expression):
+            partition_expressions = ", ".join(
+                self.sql(e) for e in expression.args.get("partition_expressions") or []
+            )
+            create_expressions = expression.args.get("create_expressions") or []
+            # Handle both static and dynamic partition definitions
+            create_sql = ", ".join(self.sql(e) for e in create_expressions)
+            return f"PARTITION BY RANGE ({partition_expressions}) ({create_sql})"
