@@ -286,6 +286,15 @@ class TestExasol(Validator):
                 "presto": "STRPOS(haystack, needle)",
             },
         )
+        self.validate_all(
+            r"SELECT REGEXP_SUBSTR('My mail address is my_mail@yahoo.com', '(?i)[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,4}') AS EMAIL",
+            write={
+                "exasol": r"SELECT REGEXP_SUBSTR('My mail address is my_mail@yahoo.com', '(?i)[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,4}') AS EMAIL",
+                "bigquery": r"SELECT REGEXP_EXTRACT('My mail address is my_mail@yahoo.com', '(?i)[a-z0-9._%+-]+@[a-z0-9.-]+\\.[a-z]{2,4}') AS EMAIL",
+                "snowflake": r"SELECT REGEXP_SUBSTR('My mail address is my_mail@yahoo.com', '(?i)[a-z0-9._%+-]+@[a-z0-9.-]+\\.[a-z]{2,4}') AS EMAIL",
+                "presto": r"SELECT REGEXP_EXTRACT('My mail address is my_mail@yahoo.com', '(?i)[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,4}') AS EMAIL",
+            },
+        )
 
     def test_datetime_functions(self):
         formats = {
@@ -375,6 +384,26 @@ class TestExasol(Validator):
             "SELECT CAST(CONVERT_TZ(CAST(CURRENT_TIMESTAMP() AS TIMESTAMP), 'UTC', 'CET') AS DATE) - 1",
         )
 
+        self.validate_all(
+            "SELECT TRUNC(CAST('2006-12-31' AS DATE), 'MM') AS TRUNC",
+            write={
+                "exasol": "SELECT TRUNC(CAST('2006-12-31' AS DATE), 'MM') AS TRUNC",
+                "presto": "SELECT DATE_TRUNC('MM', CAST('2006-12-31' AS DATE)) AS TRUNC",
+                "databricks": "SELECT TRUNC(CAST('2006-12-31' AS DATE), 'MM') AS TRUNC",
+            },
+        )
+        self.validate_all(
+            "SELECT DATE_TRUNC('minute', TIMESTAMP '2006-12-31 23:59:59') DATE_TRUNC",
+            write={
+                "exasol": "SELECT DATE_TRUNC('MINUTE', CAST('2006-12-31 23:59:59' AS TIMESTAMP)) AS DATE_TRUNC",
+                "presto": "SELECT DATE_TRUNC('MINUTE', CAST('2006-12-31 23:59:59' AS TIMESTAMP)) AS DATE_TRUNC",
+                "databricks": "SELECT DATE_TRUNC('MINUTE', CAST('2006-12-31 23:59:59' AS TIMESTAMP)) AS DATE_TRUNC",
+            },
+        )
+
+    def test_number_functions(self):
+        self.validate_identity("SELECT TRUNC(123.456, 2) AS TRUNC")
+
     def test_scalar(self):
         self.validate_all(
             "SELECT CURRENT_USER",
@@ -398,3 +427,85 @@ class TestExasol(Validator):
                 "exasol": 'CREATE OR REPLACE VIEW "schema"."v" ("col" COMMENT IS \'desc\') AS SELECT "src_col" AS "col"',
             },
         )
+        self.validate_all(
+            "HASH_SHA(x)",
+            read={
+                "clickhouse": "SHA1(x)",
+                "exasol": "HASH_SHA1(x)",
+                "presto": "SHA1(x)",
+                "trino": "SHA1(x)",
+            },
+            write={
+                "exasol": "HASH_SHA(x)",
+                "clickhouse": "SHA1(x)",
+                "bigquery": "SHA1(x)",
+                "": "SHA(x)",
+                "presto": "SHA1(x)",
+                "trino": "SHA1(x)",
+            },
+        )
+        self.validate_all(
+            "HASH_MD5(x)",
+            write={
+                "exasol": "HASH_MD5(x)",
+                "": "MD5(x)",
+                "bigquery": "TO_HEX(MD5(x))",
+                "clickhouse": "LOWER(HEX(MD5(x)))",
+                "hive": "MD5(x)",
+                "presto": "LOWER(TO_HEX(MD5(x)))",
+                "spark": "MD5(x)",
+                "trino": "LOWER(TO_HEX(MD5(x)))",
+            },
+        )
+        self.validate_all(
+            "HASHTYPE_MD5(x)",
+            write={
+                "exasol": "HASHTYPE_MD5(x)",
+                "": "MD5_DIGEST(x)",
+                "bigquery": "MD5(x)",
+                "clickhouse": "MD5(x)",
+                "hive": "UNHEX(MD5(x))",
+                "presto": "MD5(x)",
+                "spark": "UNHEX(MD5(x))",
+                "trino": "MD5(x)",
+            },
+        )
+
+        self.validate_all(
+            "HASH_SHA256(x)",
+            read={
+                "clickhouse": "SHA256(x)",
+                "presto": "SHA256(x)",
+                "trino": "SHA256(x)",
+                "postgres": "SHA256(x)",
+                "duckdb": "SHA256(x)",
+            },
+            write={
+                "exasol": "HASH_SHA256(x)",
+                "bigquery": "SHA256(x)",
+                "spark2": "SHA2(x, 256)",
+                "clickhouse": "SHA256(x)",
+                "postgres": "SHA256(x)",
+                "presto": "SHA256(x)",
+                "redshift": "SHA2(x, 256)",
+                "trino": "SHA256(x)",
+                "duckdb": "SHA256(x)",
+                "snowflake": "SHA2(x, 256)",
+            },
+        )
+        self.validate_all(
+            "HASH_SHA512(x)",
+            read={
+                "clickhouse": "SHA512(x)",
+                "presto": "SHA512(x)",
+                "trino": "SHA512(x)",
+            },
+            write={
+                "exasol": "HASH_SHA512(x)",
+                "clickhouse": "SHA512(x)",
+                "bigquery": "SHA512(x)",
+                "spark2": "SHA2(x, 512)",
+                "presto": "SHA512(x)",
+                "trino": "SHA512(x)",
+            },
+        )
